@@ -1,6 +1,6 @@
 ;;; uniline-hydra.el --- Add▶ ■─UNICODE based diagrams─■ to▶ ■─text files─■ -*- coding:utf-8; lexical-binding: t; -*-
 
-;; Copyright (C) 2024-2025  Thierry Banel
+;; Copyright (C) 2024-2026  Thierry Banel
 
 ;; Author: Thierry Banel tbanelwebmin at free dot fr
 ;; Package-Requires: ((emacs "29.1") (hydra "0.15.0"))
@@ -155,13 +155,13 @@
                 "Text dir────"
                 "Text dir─╴%s(uniline-text-direction-str)╶"
                 "\
-╭^─^─^Insert glyph^─^─^─^─^─╮╭^Rotate arrow^╮╭^─Contour─^╮╭^Text dir────^╮╭^─^─^─^──────────────╮
-│_a_,_A_rrow ▷ ▶ → ▹ ▸ ↔^^^^│╭^Tweak glyph─^╮│_c_ contour││_C-<left>_  ← ││_f_    ^^ choose font│
-│_s_,_S_quare  □ ■ ◆ ◊  ^^^^││_S-<left>_  ← ││_C_ ovwrt  ││_C-<right>_ → ││_C-t_  ^^ short hint │
-│_o_,_O_-shape · ● ◦ Ø ø^^^^││_S-<right>_ → │╰^─────────^╯│_C-<up>_    ↑ ││_?_    ^^ info-mode  │
-│_x_,_X_-cross ╳ ÷ × ± ¤^^^^││_S-<up>_    ↑ │╭^─Fill────^╮│_C-<down>_  ↓ ││_q_ _RET_ exit       │
-│_-_ _+_ _=_ _#_ self-insert││_S-<down>_  ↓ ││_i_ fill   │╰^─^───────────╯╰^─^─^─^──────────────╯
-╰^─^─^─^─^─^─^─^────────────╯╰^────────────^╯╰^─────────^╯"))
+╭^─^─^Insert glyph^^^^^─^─^───╮╭─╮╭^Rotate arrow^╮╭^Contour^╮╭^Text dir────^╮╭^─^─^─^────────╮
+│_a_,_A_rrow ▷ ▶ → ▹ ▸ ↔^^^^^^││-│╭^Tweak glyph─^╮│_c_ draw ││_C-<left>_  ← ││_f_    ^^ font │
+│_s_,_S_quare  □ ■ ◆ ◊  ^^^^^^││+││_S-<left>_  ← ││_C_ ovwrt││_C-<right>_ → ││_C-t_  ^^ hints│
+│_o_,_O_-shape · ● ◦ Ø ø^^^^^^││=││_S-<right>_ → │╰^───────^╯│_C-<up>_    ↑ ││_?_    ^^ info │
+│_x_,_X_-cross ╳ ÷ × ± ¤^^^^^^││#││_S-<up>_    ↑ │╭^─Fill──^╮│_C-<down>_  ↓ ││_q_ _RET_ exit │
+│_SPC_,_DEL_ grey  ░▒▓█ ^^^^^^││~││_S-<down>_  ↓ ││_i_ fill │╰^─^───────────╯╰^─^─^─^────────╯
+╰^─^─^─^─^─^─^─^─^─^──────────╯╰─╯╰^────────────^╯╰^───────^╯"))
               ("a" uniline-insert-fw-arrow )
               ("A" uniline-insert-bw-arrow )
               ("s" uniline-insert-fw-square)
@@ -170,6 +170,8 @@
               ("O" uniline-insert-bw-oshape)
               ("x" uniline-insert-fw-cross )
               ("X" uniline-insert-bw-cross )
+              ("SPC" uniline-insert-fw-grey)
+              ("DEL" uniline-insert-bw-grey)
               ("S-<left>"  uniline-rotate-lf←)
               ("S-<right>" uniline-rotate-ri→)
               ("S-<up>"    uniline-rotate-up↑)
@@ -184,6 +186,7 @@
               ("+" self-insert-command)
               ("=" self-insert-command)
               ("#" self-insert-command)
+              ("~" self-insert-command)
               ("f" uniline-hydra-fonts/body :exit t)
               ("c" uniline-contour          :exit t)
               ("C" (uniline-contour t)      :exit t)
@@ -231,9 +234,6 @@
               ("s"       uniline-hydra-moverect/body :exit t)
               ;; misc.
               ("C-x C-x" rectangle-exchange-point-and-mark)
-              ("C-/"     uniline--rect-undo)
-              ("C-_"     uniline--rect-undo)
-              ("C-x u"   uniline--rect-undo)
               ("C-t"     uniline-toggle-hints)
               ("TAB"     uniline-toggle-hints)
               ("?"      (info "(uniline) Rectangular actions"))
@@ -247,10 +247,11 @@
 ╭^Move ^rect╮╭────^Draw^ rect────╮╭^─Rect^─╮╭^Brush^╮╭──^Misc^─────────╮
 │_<right>_ →││_r_     trace inner││_c_ copy││_-_ ╭─╯││_s_   alt styles │
 │_<left>_  ←││_R_     trace outer││_k_ kill││_+_ ┏━┛││_f_   choose font│
-│_<up>_    ↑││_C-r_   ovewr inner││_y_ yank││_=_ ╔═╝││_C-/_ undo       │
-│_<down>_  ↓││_C-S-R_ ovewr outer│╰^^┬─────╯╯_#_ ▄▄▟││_C-t_ short hint │
-╰^─────^────╯│_i_     fill       │ ^^│_<delete>_ DEL││_RET_ exit       │
- ^     ^     ╰^────^─────────────╯ ^^╰^────────^────╯╰^───^────────────╯
+│_<up>_    ↑││_C-r_   ovewr inner││_y_ yank││_=_ ╔═╝││_C-t_ short hints│
+│_<down>_  ↓││_C-S-R_ ovewr outer│╰^^──────╯│_#_ ▄▄▟││_?_   info       │
+╰^─────^────╯│_i_     fill       │ ^^╭──────╯_~_ ┄┄┄││_RET_ exit       │
+ ^     ^     ╰^────^─────────────╯ ^^│_<delete>_ DEL│╰^───^────────────╯
+ ^     ^      ^    ^               ^^╰^────────^────╯
 "
               ("<right>" uniline-move-rect-ri→)
               ("<left>"  uniline-move-rect-lf←)
@@ -277,15 +278,13 @@
               ("<kp-add>"       uniline-set-brush-2)
               ("="              uniline-set-brush-3)
               ("#"              uniline-set-brush-block)
+              ("~"              uniline-set-brush-dot-toggle)
 
               ("C-t" uniline-toggle-hints)
               ("TAB" uniline-toggle-hints)
               ("?"  (info "(uniline) Rectangular actions"))
               ("f"     uniline-hydra-fonts/body      :exit t)
               ("s"     uniline-hydra-alt-styles/body :exit t)
-              ("C-/"   uniline--rect-undo)
-              ("C-_"   uniline--rect-undo)
-              ("C-x u" uniline--rect-undo)
               ("C-x C-x" rectangle-exchange-point-and-mark)
               ("RET"   uniline--rect-quit :exit t))
 
@@ -340,7 +339,7 @@ Otherwise, the arrows & shapes hydra is invoked."
           ,uniline-hydra-arrows/hint
         ,(eval-when-compile
            (uniline--color-hint
-            "glyph:^aAsSoOxX-+=#^ arr&tweak:^S-→←↑↓^ text-dir:^C-→←↑↓^ ^c^ontour f^i^ll ^f^onts ^C-t^")))
+            "glyph:^aAsSoOxX SPC DEL-+=#~^ arr&tweak:^S-→←↑↓^ txt-dir:^C-→←↑↓^ ^c^ontour f^i^ll ^f^ont ^C-t^")))
      uniline-hydra-fonts/hint
      `(if (eq uniline-hint-style t)
           ,uniline-hydra-fonts/hint
